Task: Twitter
==============
Description: Twitter data from: https://github.com/Marsan-Ma/chat_corpus/. No train/valid/test split was provided so 10k for valid and 10k for test was chosen at random.

Tags: #Twitter, #All, #ChitChat

